@@ -1,6 +1,7 @@
 """
 Parser for Boto3 ServiceResource, produces `structires.ServiceResource`.
 """
+import inspect
 from typing import List, Optional
 
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
@@ -21,6 +22,7 @@ from mypy_boto3_builder.service_name import ServiceName
 from mypy_boto3_builder.structures.attribute import Attribute
 from mypy_boto3_builder.structures.service_resource import ServiceResource
 from mypy_boto3_builder.type_annotations.internal_import import InternalImport
+from mypy_boto3_builder.utils.strings import get_short_docstring
 
 
 def parse_service_resource(
@@ -55,11 +57,15 @@ def parse_service_resource(
             method = shape_method_map[method_name]
         else:
             method = parse_method("ServiceResource", method_name, public_method, service_name)
-        method.docstring = (
-            "[Show boto3 documentation]"
-            f"({service_name.get_boto3_doc_link('ServiceResource', method_name)})\n"
-            "[Show boto3-stubs documentation]"
-            f"({service_name.get_doc_link('service_resource', result.name, f'{method_name} method')})"
+        docstring = get_short_docstring(inspect.getdoc(public_method) or "")
+        method.docstring = "".join(
+            (
+                f"{docstring}\n\n" if docstring else "",
+                "[Show boto3 documentation]",
+                f"({service_name.get_boto3_doc_link('ServiceResource', method_name)})\n",
+                "[Show boto3-stubs documentation]",
+                f"({service_name.get_doc_link('service_resource', result.name, f'{method_name} method')})",
+            )
         )
         result.methods.append(method)
 
