@@ -1,12 +1,13 @@
 """
 Module-level function.
 """
-from typing import Iterable, Set
+from typing import Iterable, Optional, Set
 
 from mypy_boto3_builder.import_helpers.import_record import ImportRecord
 from mypy_boto3_builder.structures.argument import Argument
 from mypy_boto3_builder.type_annotations.fake_annotation import FakeAnnotation
 from mypy_boto3_builder.type_annotations.type import Type
+from mypy_boto3_builder.type_annotations.type_typed_dict import TypeTypedDict
 
 
 class Function:
@@ -31,6 +32,41 @@ class Function:
         self.decorators = list(decorators)
         self.body_lines = body_lines
         self.type_ignore = type_ignore
+        self.request_type_annotation: Optional[TypeTypedDict] = None
+
+    @property
+    def short_docstring(self) -> str:
+        """
+        Docstring without documentation links.
+        """
+        if not self.docstring:
+            return self.docstring
+
+        short_docstring = self.docstring.strip().split("\n\n")[0]
+        if short_docstring.startswith("["):
+            return ""
+        return short_docstring
+
+    def get_request_type_annotation(self, name: str) -> Optional[TypeTypedDict]:
+        """
+        Get TypedDict based on function arguments.
+        """
+        result = TypeTypedDict(name)
+        for argument in self.arguments:
+            if argument.is_kwflag():
+                continue
+
+            if not argument.type_annotation:
+                continue
+            result.add_attribute(
+                argument.name,
+                argument.type_annotation,
+                required=argument.required,
+            )
+
+        if not result.children:
+            return None
+        return result
 
     @property
     def body(self) -> str:
